@@ -1,4 +1,5 @@
 from copy import copy
+from enum import Enum
 from typing import (
     Any,
     Callable,
@@ -19,6 +20,7 @@ from .ast import Node
 __all__ = [
     "Visitor",
     "ParallelVisitor",
+    "VisitorAction",
     "visit",
     "BREAK",
     "SKIP",
@@ -28,10 +30,26 @@ __all__ = [
 ]
 
 
-# Special return values for the visitor methods:
+class VisitorActionEnum(Enum):
+    """Special return values for the visitor methods.
+
+    You can also use the values of this enum directly.
+    """
+
+    BREAK = True
+    SKIP = False
+    REMOVE = Ellipsis
+
+
+VisitorAction = Optional[VisitorActionEnum]
+
 # Note that in GraphQL.js these are defined differently:
 # BREAK = {}, SKIP = false, REMOVE = null, IDLE = undefined
-BREAK, SKIP, REMOVE, IDLE = True, False, Ellipsis, None
+
+BREAK = VisitorActionEnum.BREAK
+SKIP = VisitorActionEnum.SKIP
+REMOVE = VisitorActionEnum.REMOVE
+IDLE = None
 
 # Default map from visitor kinds to their traversable node attributes:
 QUERY_DOCUMENT_KEYS: Dict[str, Tuple[str, ...]] = {
@@ -155,7 +173,7 @@ class Visitor:
     # Provide special return values as attributes
     BREAK, SKIP, REMOVE, IDLE = BREAK, SKIP, REMOVE, IDLE
 
-    def __init_subclass__(cls):
+    def __init_subclass__(cls) -> None:
         """Verify that all defined handlers are valid."""
         super().__init_subclass__()
         for attr, val in cls.__dict__.items():
@@ -177,13 +195,12 @@ class Visitor:
                     ):
                         raise TypeError(f"Invalid AST node kind: {kind}.")
 
-    @classmethod
-    def get_visit_fn(cls, kind, is_leaving=False) -> Callable:
+    def get_visit_fn(self, kind: str, is_leaving: bool = False) -> Callable:
         """Get the visit function for the given node kind and direction."""
         method = "leave" if is_leaving else "enter"
-        visit_fn = getattr(cls, f"{method}_{kind}", None)
+        visit_fn = getattr(self, f"{method}_{kind}", None)
         if not visit_fn:
-            visit_fn = getattr(cls, method, None)
+            visit_fn = getattr(self, method, None)
         return visit_fn
 
 
@@ -197,7 +214,11 @@ class Stack(NamedTuple):
     prev: Any  # 'Stack' (python/mypy/issues/731)
 
 
-def visit(root: Node, visitor: Visitor, visitor_keys=None) -> Any:
+def visit(
+    root: Node,
+    visitor: Visitor,
+    visitor_keys: Optional[Dict[str, Tuple[str, ...]]] = None,
+) -> Any:
     """Visit each node in an AST.
 
     :func:`~.visit` will walk through an AST using a depth first traversal, calling the
@@ -253,7 +274,7 @@ def visit(root: Node, visitor: Visitor, visitor_keys=None) -> Any:
             for edit_key, edit_value in edits:
                 if in_array:
                     edit_key -= edit_offset
-                if in_array and edit_value is REMOVE:
+                if in_array and (edit_value is REMOVE or edit_value is Ellipsis):
                     node.pop(edit_key)
                     edit_offset += 1
                 else:
@@ -290,12 +311,12 @@ def visit(root: Node, visitor: Visitor, visitor_keys=None) -> Any:
                 raise TypeError(f"Invalid AST Node: {inspect(node)}.")
             visit_fn = visitor.get_visit_fn(node.kind, is_leaving)
             if visit_fn:
-                result = visit_fn(visitor, node, key, parent, path, ancestors)
+                result = visit_fn(node, key, parent, path, ancestors)
 
-                if result is BREAK:
+                if result is BREAK or result is True:
                     break
 
-                if result is SKIP:
+                if result is SKIP or result is False:
                     if not is_leaving:
                         path_pop()
                         continue
@@ -349,30 +370,36 @@ class ParallelVisitor(Visitor):
         self.visitors = visitors
         self.skipping: List[Any] = [None] * len(visitors)
 
-    def enter(self, node, *args):
+    def enter(self, node: Node, *args: Any) -> Optional[VisitorAction]:
         skipping = self.skipping
         for i, visitor in enumerate(self.visitors):
             if not skipping[i]:
                 fn = visitor.get_visit_fn(node.kind)
                 if fn:
-                    result = fn(visitor, node, *args)
-                    if result is SKIP:
+                    result = fn(node, *args)
+                    if result is SKIP or result is False:
                         skipping[i] = node
-                    elif result == BREAK:
+                    elif result is BREAK or result is True:
                         skipping[i] = BREAK
                     elif result is not None:
                         return result
+        return None
 
-    def leave(self, node, *args):
+    def leave(self, node: Node, *args: Any) -> Optional[VisitorAction]:
         skipping = self.skipping
         for i, visitor in enumerate(self.visitors):
             if not skipping[i]:
                 fn = visitor.get_visit_fn(node.kind, is_leaving=True)
                 if fn:
-                    result = fn(visitor, node, *args)
-                    if result == BREAK:
+                    result = fn(node, *args)
+                    if result is BREAK or result is True:
                         skipping[i] = BREAK
-                    elif result is not None and result is not SKIP:
+                    elif (
+                        result is not None
+                        and result is not SKIP
+                        and result is not False
+                    ):
                         return result
             elif skipping[i] is node:
                 skipping[i] = None
+        return None
