@@ -1,7 +1,19 @@
 from math import nan
-from typing import Any, Dict, Optional
+from typing import Any, Callable, Dict, Optional, Union
+
+from ..language import (
+    ValueNode,
+    BooleanValueNode,
+    EnumValueNode,
+    FloatValueNode,
+    IntValueNode,
+    ListValueNode,
+    NullValueNode,
+    ObjectValueNode,
+    StringValueNode,
+    VariableNode,
+)
 
-from ..language import ValueNode
 from ..pyutils import inspect, Undefined
 
 __all__ = ["value_from_ast_untyped"]
@@ -37,47 +49,55 @@ def value_from_ast_untyped(
     )
 
 
-def value_from_null(_value_node, _variables):
+def value_from_null(_value_node: NullValueNode, _variables: Any) -> Any:
     return None
 
 
-def value_from_int(value_node, _variables):
+def value_from_int(value_node: IntValueNode, _variables: Any) -> Any:
     try:
         return int(value_node.value)
     except ValueError:
         return nan
 
 
-def value_from_float(value_node, _variables):
+def value_from_float(value_node: FloatValueNode, _variables: Any) -> Any:
     try:
         return float(value_node.value)
     except ValueError:
         return nan
 
 
-def value_from_string(value_node, _variables):
+def value_from_string(
+    value_node: Union[BooleanValueNode, EnumValueNode, StringValueNode], _variables: Any
+) -> Any:
     return value_node.value
 
 
-def value_from_list(value_node, variables):
+def value_from_list(
+    value_node: ListValueNode, variables: Optional[Dict[str, Any]]
+) -> Any:
     return [value_from_ast_untyped(node, variables) for node in value_node.values]
 
 
-def value_from_object(value_node, variables):
+def value_from_object(
+    value_node: ObjectValueNode, variables: Optional[Dict[str, Any]]
+) -> Any:
     return {
         field.name.value: value_from_ast_untyped(field.value, variables)
         for field in value_node.fields
     }
 
 
-def value_from_variable(value_node, variables):
+def value_from_variable(
+    value_node: VariableNode, variables: Optional[Dict[str, Any]]
+) -> Any:
     variable_name = value_node.name.value
     if not variables:
         return Undefined
     return variables.get(variable_name, Undefined)
 
 
-_value_from_kind_functions = {
+_value_from_kind_functions: Dict[str, Callable] = {
     "null_value": value_from_null,
     "int_value": value_from_int,
     "float_value": value_from_float,
