@@ -1,3 +1,5 @@
+from typing import Any
+
 from ...error import GraphQLError
 from ...language import FragmentSpreadNode
 from . import ValidationRule
@@ -12,7 +14,7 @@ class KnownFragmentNamesRule(ValidationRule):
     fragments defined in the same document.
     """
 
-    def enter_fragment_spread(self, node: FragmentSpreadNode, *_args):
+    def enter_fragment_spread(self, node: FragmentSpreadNode, *_args: Any) -> None:
         fragment_name = node.name.value
         fragment = self.context.get_fragment(fragment_name)
         if not fragment:
